/* $Workfile: OtxCstD.h $   $Revision: 11 $    $Modtime: 10/21/05 4:51p $  */
#ifndef OTX_CST_DEF_H
#define OTX_CST_DEF_H
/*******************************************************************************

  @doc PublicHwApi OtxCstD

  Copyright (C) 2004 - 2005 Odin TeleSystems Inc., All Rights Reserved

  OTX Generic Hardware Driver API

  @module
  OtxCstD | Constants, Macros, and Types for the C54CST DSP Related functions

  @contents2
  OtxCstD.h |

  @index enum type struct | OtxCstD

  @contents2
  OTX C54CST Releated Logical Data Filter Device Macros, Constants, and Types |

  @head3 OtxCstXXX Macro, Constant, and Type Reference |

  @index enum type struct | OtxCstD

*******************************************************************************/

#include "OtxType.h"
#include "OtxErr.h"

#ifdef __cplusplus
  extern "C" {
#endif


/******************************************************************************
  @enum
    POTS Error Result Codes
******************************************************************************/
enum OtxCstPotsResultCodesE {
  OTX_CST_PTOS_RES_XXX   = OTX_RES_END +  0 ,  // @emem xxx

  OTX_CST_POTS_RES_END   = OTX_RES_END +  1 
};

typedef enum OtxCstPotsResultCodesE OtxCstPotsResultCodesE;


/*******************************************************************************
  @enum
    POTS Notify Causes. 
*******************************************************************************/
enum OtxCstPotsEventCodeE {

  OTX_CST_POTS_RING_SIGNAL_DETECTED          = 1,     // @emem A ring signal has been detected
  OTX_CST_POTS_END_RING_SIGNAL_DETECTED      = 2,     // @emem End of ring signal has been detected
  OTX_CST_POTS_AUTO_END_RING_SIGNAL_DETECTED = 3,     // @emem End of ring signal has been detected
  OTX_CST_POTS_TIP_RING_REVERSAL_DETECTED    = 4,     // @emem Tip/Ring reversal detected. The other end hung up upon us.
  OTX_CST_POTS_CALLER_ID_DETECTED            = 5,     // @emem Caller id detected. 
                                                      // The parameter of this event is the caller id result code. 
                                                      // A successful caller id detection has the 
                                                      // <e OtxCstCidErrorCodesE.OTX_CST_CALLER_ID_EC_NOERROR> value 
                                                      // as the <e OtxEventDataS.m_nParam> field of this event. 
                                                      // Any other code indicates an error condition.
                                                      // The caller id string itself can be read by reading the 
                                                      // <e OtxCstPotsDeviceAttributesE.OTX_ATTR_CST_POTS_CALLER_ID> attribute
                                                      // directly after this event has occurred.
  OTX_CST_POTS_OFF_HOOK_COMPLETE             = 6,     // @emem Off-Hook
  OTX_CST_POTS_ON_HOOK_COMPLETE              = 7,     // @emem On-Hook
  OTX_CST_POTS_ON_HOOK_LINE_MON_COMPLETE     = 8,     // @emem On-Hook in Line Monitor mode
  OTX_CST_POTS_SENSE_LINE_COMPLETE           = 9,     // @emem Line Voltage or Loope current
  OTX_CST_POTS_PULSE_GEN_COMPLETE            = 10,    // @emem Pulse generation

  OTX_CST_POTS_READ_REG_COMPLETE             = 11,    // @emem For internal use only.
  OTX_CST_POTS_WRITE_REG_COMPLETE            = 12,    // @emem For internal use only.

  OTX_CST_POTS_END_OF_EVENT_CODES            = 13
};

typedef enum OtxCstPotsEventCodeE OtxCstPotsEventCodeE;



/*******************************************************************************
  @enum 
    POTS Device Attributes
*******************************************************************************/
enum OtxCstPotsDeviceAttributesE {
  OTX_ATTR_CST_POTS_MULTIPLE_OFF_HOOK_THRESHOLD  = OTX_ATTR_END + 0, // @emem (OTX_ATTRIB_UINT32) Read/Write. 0                         <lt> LineVoltage <lt>= nMultipleOffHookThreshold :  No line is connected          
  OTX_ATTR_CST_POTS_SINGLE_OFF_HOOK_THRESHOLD    = OTX_ATTR_END + 1, // @emem (OTX_ATTRIB_UINT32) Read/Write. nMultipleOffHookThreshold <lt> LineVoltage <lt>= nSingleOffHookThreshold   :  Multiple phones are off-hook  
  OTX_ATTR_CST_POTS_ON_HOOK_THRESHOLD            = OTX_ATTR_END + 2, // @emem (OTX_ATTRIB_UINT32) Read/Write. nSingleOffHookThreshold   <lt> LineVoltage <lt>= nOnOffHookThreshold       :  Single phone is off-hook      

  OTX_ATTR_CST_POTS_CALLER_ID                    = OTX_ATTR_END + 3, // @emem (OTX_ATTRIB_SZ) Read/Write. Last received Caller Id string as indicated 
                                                                     // by the <e OtxCstPotsEventCodeE.OTX_CST_POTS_CALLER_ID_DETECTED> event. 
                                                                     // This string is reset to '\0' when read or written to. 
                                                                     // <nl> If this string is not read before the next caller id string is received, the caller id string is lost, and 
                                                                     // reading of this attribute will return a <e OtxCommonResultCodesE.OTX_RES_BUSY> return code. 
                                                                     // In that case this attribute has to be written to (any value), in order to clear the "overrun".

  OTX_ATTR_CST_POTS_CALLER_ID_PRESENTATION_MESSAGE = OTX_ATTR_END + 4, // @emem (OTX_ATTRIB_OCTETS) Read/Write. Last received Caller Id Presentation message. See <t OtxCstCidPresentationMessageS>.
                                                                     // by the <e OtxCstPotsEventCodeE.OTX_CST_POTS_CALLER_ID_DETECTED> event. 
                                                                     // This struct is reset to zero when read or written to. 
                                                                     // <nl> If this struct is not read before the next caller id string is received, the caller id presentation message is lost, and 
                                                                     // reading of this attribute will return a <e OtxCommonResultCodesE.OTX_RES_BUSY> return code. 
                                                                     // In that case this attribute has to be written to (any value), in order to clear the "overrun".



  OTX_ATTR_CST_POTS_END                          = OTX_ATTR_END + 5
};

typedef enum OtxCstPotsDeviceAttributesE OtxCstPotsDeviceAttributesE;


/*******************************************************************************
  @enum 
    POTS Country Specific configuration sets (to be used with the <e OtxCstPotsDeviceAttributesE.OTX_ATTR_CST_POTS_CFG_SET> attribute
*******************************************************************************/
enum OtxCstPotsCfgSetE {
  OTX_CST_POTS_CFG_SET_USA       = 0,  // @emem POTS configuration for USA
  OTX_CST_POTS_CFG_SET_GERMANY   = 1,  // @emem POTS configuration for Germany
  OTX_CST_POTS_CFG_SET_UK        = 2,  // @emem POTS configuration for United Kingdom
  OTX_CST_POTS_CFG_SET_FRANCE    = 3,  // @emem POTS configuration for France
  OTX_CST_POTS_CFG_SET_AUSTRALIA = 4,  // @emem POTS configuration for Australia
  OTX_CST_POTS_CFG_SET_JAPAN     = 5,  // @emem POTS configuration for Japan
};
typedef enum OtxCstPotsCfgSetE OtxCstPotsCfgSetE;




/******************************************************************************
  @enum
    Echo Cancel Error Result Codes
******************************************************************************/
enum OtxCstEchoCancelResultCodesE {
  OTX_CST_ECHO_CANCEL_RES_XXX   = OTX_RES_END +  0 ,  // @emem xxx

  OTX_CST_ECHO_CANCEL_RES_END   = OTX_RES_END +  1 
};

typedef enum OtxCstEchoCancelResultCodesE OtxCstEchoCancelResultCodesE;


/******************************************************************************
  @enum
    Echo Cancel Event Codes
******************************************************************************/
enum OtxCstEchoCancelEventCodesE {
  OTX_CST_ECHO_CANCEL_EC_XXX            = 0x00, // @emem xxx
    
  OTX_CST_ECHO_CANCEL_END_OF_EVENT_CODES
};

typedef enum OtxCstEchoCancelEventCodesE OtxCstEchoCancelEventCodesE;


/******************************************************************************
  @enum 
    Echo Cancel Attributes
******************************************************************************/
enum OtxCstEchoCancelAttributesE {
  OTX_ATTR_CST_ECHO_CANCEL_XXX                 = OTX_ATTR_END + 0,  // @emem (OTX_ATTRIB_UINT32) Read/Write. 
                                                                  // Dummy

  OTX_ATTR_CST_ECHO_CANCEL_END                 = OTX_ATTR_END + 1
};

typedef enum OtxCstEchoCancelAttributesE OtxCstEchoCancelAttributesE;






/******************************************************************************
  @enum
    Voice Mixer Error Result Codes
******************************************************************************/
enum OtxCstVoiceMixerResultCodesE {
  OTX_CST_VOICE_MIXER_RES_XXX   = OTX_RES_END +  0 ,  // @emem xxx

  OTX_CST_VOICE_MIXER_RES_END   = OTX_RES_END +  1 
};

typedef enum OtxCstVoiceMixerResultCodesE OtxCstVoiceMixerResultCodesE;


/******************************************************************************
  @enum
    Voice Mixer Event Codes
******************************************************************************/
enum OtxCstVoiceMixerEventCodesE {
  OTX_CST_VOICE_MIXER_EC_XXX            = 0x00, // @emem xxx
    
  OTX_CST_VOICE_MIXER_END_OF_EVENT_CODES
};

typedef enum OtxCstVoiceMixerEventCodesE OtxCstVoiceMixerEventCodesE;


/******************************************************************************
  @enum 
    Voice Mixer Attributes
******************************************************************************/
enum OtxCstVoiceMixerAttributesE {
  OTX_ATTR_CST_VOICE_MIXER_XXX                 = OTX_ATTR_END + 0,  // @emem (OTX_ATTRIB_UINT32) Read/Write. 
                                                                  // Dummy

  OTX_ATTR_CST_VOICE_MIXER_END                 = OTX_ATTR_END + 1
};

typedef enum OtxCstVoiceMixerAttributesE OtxCstVoiceMixerAttributesE;





/******************************************************************************
  @enum
    Comfort Noice Generator Error Result Codes
******************************************************************************/
enum OtxCstComfortNoiseGeneratorResultCodesE {
  OTX_CST_COMFORT_NOISE_GENERATOR_RES_XXX   = OTX_RES_END +  0 ,  // @emem xxx

  OTX_CST_COMFORT_NOISE_GENERATOR_RES_END   = OTX_RES_END +  1
};

typedef enum OtxCstComfortNoiseGeneratorResultCodesE OtxCstComfortNoiseGeneratorResultCodesE;


/******************************************************************************
  @enum
    Comfort Noice Generator Event Codes
******************************************************************************/
enum OtxCstComfortNoiseGeneratorEventCodesE {
  OTX_CST_COMFORT_NOISE_GENERATOR_EC_XXX            = 0x00, // @emem xxx
    
  OTX_CST_COMFORT_NOISE_GENERATOR_END_OF_EVENT_CODES
};

typedef enum OtxCstComfortNoiseGeneratorEventCodesE OtxCstComfortNoiseGeneratorEventCodesE;


/******************************************************************************
  @enum 
    Comfort Noice Generator Attributes
******************************************************************************/
enum OtxCstComfortNoiseGeneratorAttributesE {
  OTX_ATTR_CST_COMFORT_NOISE_GENERATOR_XXX                 = OTX_ATTR_END + 0,  // @emem (OTX_ATTRIB_UINT32) Read/Write. 
                                                                  // Dummy

  OTX_ATTR_CST_COMFORT_NOISE_GENERATOR_END                 = OTX_ATTR_END + 1
};

typedef enum OtxCstComfortNoiseGeneratorAttributesE OtxCstComfortNoiseGeneratorAttributesE;




/******************************************************************************
  @enum
    DTMF Dialer Error Result Codes
******************************************************************************/
enum OtxCstDtmfDialerResultCodesE {
  OTX_CST_DTMF_DIALER_RES_INVALID_DTMF_VALUE   = OTX_RES_END +  0 ,  // @emem Invalid DTMF value        
  OTX_CST_DTMF_DIALER_RES_BUSY                 = OTX_RES_END +  1 ,  // @emem DTMF Dialer is busy

  OTX_CST_DTMF_DIALER_RES_END                  = OTX_RES_END +  2
};

typedef enum OtxCstDtmfDialerResultCodesE OtxCstDtmfDialerResultCodesE;


/******************************************************************************
  @enum
    DTMF Dialer Event Codes
******************************************************************************/
enum OtxCstDtmfDialerEventCodesE {
  OTX_CST_DTMF_DIALER_EC_COMPLETE            = 0x00,                // @emem xxx
    
  OTX_CST_DTMF_DIALER_END_OF_EVENT_CODES
};

typedef enum OtxCstDtmfDialerEventCodesE OtxCstDtmfDialerEventCodesE;


/******************************************************************************
  @enum 
    DTMF Dialer Attributes
******************************************************************************/
enum OtxCstDtmfDialerAttributesE {
  OTX_ATTR_CST_DTMF_DIALER_XXX                 = OTX_ATTR_END + 0,  // @emem (OTX_ATTRIB_UINT32) Read/Write. 
                                                                  // Dummy

  OTX_ATTR_CST_DTMF_DIALER_END                 = OTX_ATTR_END + 1
};

typedef enum OtxCstDtmfDialerAttributesE OtxCstDtmfDialerAttributesE;




/******************************************************************************
  @enum
    CPT Generator Error Result Codes
******************************************************************************/
enum OtxCstCptGeneratorResultCodesE {
  OTX_CST_CPT_GENERATOR_RES_INVALID_CPT_VALUE   = OTX_RES_END +  0 ,  // @emem Invalid CPT value        
  OTX_CST_CPT_GENERATOR_RES_BUSY                 = OTX_RES_END +  1 ,  // @emem CPT Generator is busy

  OTX_CST_CPT_GENERATOR_RES_END                  = OTX_RES_END +  2
};

typedef enum OtxCstCptGeneratorResultCodesE OtxCstCptGeneratorResultCodesE;


/******************************************************************************
  @enum
    CPT Generator Event Codes
******************************************************************************/
enum OtxCstCptGeneratorEventCodesE {
  OTX_CST_CPT_GENERATOR_EC_COMPLETE            = 0x00,                // @emem xxx
    
  OTX_CST_CPT_GENERATOR_END_OF_EVENT_CODES
};

typedef enum OtxCstCptGeneratorEventCodesE OtxCstCptGeneratorEventCodesE;


/******************************************************************************
  @enum 
    CPT Generator Attributes
******************************************************************************/
enum OtxCstCptGeneratorAttributesE {
  OTX_ATTR_CST_CPT_GENERATOR_XXX                 = OTX_ATTR_END + 0,  // @emem (OTX_ATTRIB_UINT32) Read/Write. 
                                                                  // Dummy

  OTX_ATTR_CST_CPT_GENERATOR_END                 = OTX_ATTR_END + 1
};

typedef enum OtxCstCptGeneratorAttributesE OtxCstCptGeneratorAttributesE;




/******************************************************************************
  @enum
    Voice Activity Detector Error Result Codes
******************************************************************************/
enum OtxCstVoiceActivityResultCodesE {
  OTX_CST_VOICE_ACTIVITY_DETECTOR_RES_END     = OTX_RES_END +  0
};

typedef enum OtxCstVoiceActivityResultCodesE OtxCstVoiceActivityResultCodesE;


/******************************************************************************
  @enum
    Voice Activity Detector Event Codes
******************************************************************************/
enum OtxCstVoiceActivityEventCodesE {

  OTX_CST_VOICE_ACTIVITY_DETECTOR_EC_NOISE          = 0x00, // @emem Noise (no voice) present
  OTX_CST_VOICE_ACTIVITY_DETECTOR_EC_NOISE_HANGOVER = 0x01, // @emem Noise Hangover. We have had noise, but possible entering into voice
  OTX_CST_VOICE_ACTIVITY_DETECTOR_EC_VOICE          = 0x02, // @emem Voice present
  OTX_CST_VOICE_ACTIVITY_DETECTOR_EC_VOICE_HANGOVER = 0x03, // @emem Voice Hangover. We had voice present, but it has just disappeared
  OTX_CST_VOICE_ACTIVITY_DETECTOR_EC_UNKNOWN        = 0x04, // @emem Undetermined voice activity status
    
  OTX_CST_VOICE_ACTIVITY_DETECTOR_END_OF_EVENT_CODES
};

typedef enum OtxCstVoiceActivityEventCodesE OtxCstVoiceActivityEventCodesE;


/******************************************************************************
  @enum 
    Voice Activity Detector Attributes
******************************************************************************/
enum OtxCstVoiceActivityDetectorAttributesE {
  OTX_ATTR_CST_VOICE_ACTIVITY_DETECTOR_XXX        = OTX_ATTR_END + 0,  // @emem (OTX_ATTRIB_UINT32) Read/Write. 
                                                                       // Dummy

  OTX_ATTR_CST_VOICE_ACTIVITY_DETECTOR_END        = OTX_ATTR_END + 1
};

typedef enum OtxCstVoiceActivityDetectorAttributesE OtxCstVoiceActivityDetectorAttributesE;




/******************************************************************************
  @enum
    DTMF Detector Error Result Codes
******************************************************************************/
enum OtxCstDtmfDetectorResultCodesE {
  OTX_CST_DTMF_DETECTOR_RES_NO_TONE         = OTX_RES_END +  0 ,  // @emem No DTMF tone presently detected        
  OTX_CST_DTMF_DETECTOR_RES_TONE            = OTX_RES_END +  1 ,  // @emem DTMF tone is presently detected        
  OTX_CST_DTMF_DETECTOR_RES_END             = OTX_RES_END +  2
};

typedef enum OtxCstDtmfDetectorResultCodesE OtxCstDtmfDetectorResultCodesE;


/******************************************************************************
  @enum
    DTMF Detector Event Codes
******************************************************************************/
enum OtxCstDtmfDetectorEventCodesE {

  OTX_CST_DTMF_DETECTOR_EC_MTONESTART          = 0x00,  // @emem Indicates successful detection of the first frame of the first time slot.
                                                       // <nl> <e OtxCstEventDataS.m_nParam> contains the digit. 
                                                       // <nl> 0 represents DTMF digit 0  (941Hz/1336Hz)    
                                                       // <nl> 1 represents DTMF digit 1  (697Hz/1209Hz)    
                                                       // <nl> 2 represents DTMF digit 2  (697Hz/1336Hz)    
                                                       // <nl> 3 represents DTMF digit 3  (697Hz/1477Hz)    
                                                       // <nl> 4 represents DTMF digit 4  (770Hz/1209Hz)    
                                                       // <nl> 5 represents DTMF digit 5  (770Hz/1336Hz)    
                                                       // <nl> 6 represents DTMF digit 6  (770Hz/1477Hz)    
                                                       // <nl> 7 represents DTMF digit 7  (852Hz/1209Hz)    
                                                       // <nl> 8 represents DTMF digit 8  (852Hz/1336Hz)    
                                                       // <nl> 9 represents DTMF digit 9  (852Hz/1477Hz)      
                                                       // <nl> 10 represents A (697Hz/1633Hz)
                                                       // <nl> 11 represents B (770Hz/1633Hz)
                                                       // <nl> 12 represents C (852Hz/1633Hz)
                                                       // <nl> 13 represents D (941Hz/1633Hz)
                                                       // <nl> 14 represents * (941Hz/1209Hz)
                                                       // <nl> 15 represents # (941Hz/1477Hz)


  OTX_CST_DTMF_DETECTOR_EC_MTONE               = 0x01, // @emem Indicates successful detection of time slot.
  OTX_CST_DTMF_DETECTOR_EC_MSIGNALEND          = 0x02, // @emem Indicates successful signal detection
                                                       // <nl> <e OtxCstEventDataS.m_nParam> contains the digit. Please
                                                       // see <e OtxCstDtmfDetectorEventCodesE.OTX_CST_DTMF_DETECTOR_EC_MTONESTART>
                                                       // for a description of the tone value.
  OTX_CST_DTMF_DETECTOR_EC_MFAIL               = 0x03, // @emem Indicates the end of the "detected" state. When no "detected" state was
                                                       // established, this message is not issued.
  OTX_CST_DTMF_DETECTOR_EC_MPATTERNEND         = 0x04, // @emem Indicates the end of signal sequence, works only for repeated signals
                                                       // (e.g. BUSY, RING BACK, etc.)
    
  OTX_CST_DTMF_DETECTOR_END_OF_EVENT_CODES
};

typedef enum OtxCstDtmfDetectorEventCodesE OtxCstDtmfDetectorEventCodesE;


/******************************************************************************
  @enum 
    DTMF Detector Attributes
******************************************************************************/
enum OtxCstDtmfDetectorAttributesE {
  OTX_ATTR_CST_DTMF_DETECTOR_MIN_DURATION        = OTX_ATTR_END + 0,  // @emem (OTX_ATTRIB_UINT32) Read/Write. 
                                                                  // Minimum required duration (in milliseconds) of a tone
                                                                  // before it is reported as a detected tone.

  OTX_ATTR_CST_DTMF_DETECTOR_END                 = OTX_ATTR_END + 1
};

typedef enum OtxCstDtmfDetectorAttributesE OtxCstDtmfDetectorAttributesE;




/******************************************************************************
  @enum
    CPT Detector Error Result Codes
******************************************************************************/
enum OtxCstCptDetectorResultCodesE {
  OTX_CST_CPT_DETECTOR_RES_NO_TONE         = OTX_RES_END +  0 ,  // @emem No CPT tone presently detected        
  OTX_CST_CPT_DETECTOR_RES_TONE            = OTX_RES_END +  1 ,  // @emem CPT tone is presently detected        
  OTX_CST_CPT_DETECTOR_RES_END             = OTX_RES_END +  2
};

typedef enum OtxCstCptDetectorResultCodesE OtxCstCptDetectorResultCodesE;


/******************************************************************************
  @enum
    CPT Detector Event Codes
******************************************************************************/
enum OtxCstCptDetectorEventCodesE {

  OTX_CST_CPT_DETECTOR_EC_MTONESTART          = 0x00,  // @emem Indicates successful detection of the first frame of the first time slot.
                                                       // <nl> <e OtxCstEventDataS.m_nParam> contains the symbol. 
                                                       // <nl> 0 represents CPT xxx 
                                                       // <nl> 1 represents CPT yyy


  OTX_CST_CPT_DETECTOR_EC_MTONE               = 0x01, // @emem Indicates successful detection of time slot.
  OTX_CST_CPT_DETECTOR_EC_MSIGNALEND          = 0x02, // @emem Indicates successful signal detection
                                                       // <nl> <e OtxCstEventDataS.m_nParam> contains the digit. Please
                                                       // see <e OtxCstCptDetectorEventCodesE.OTX_CST_CPT_DETECTOR_EC_MTONESTART>
                                                       // for a description of the tone value.
  OTX_CST_CPT_DETECTOR_EC_MFAIL               = 0x03, // @emem Indicates the end of the "detected" state. When no "detected" state was
                                                       // established, this message is not issued.
  OTX_CST_CPT_DETECTOR_EC_MPATTERNEND         = 0x04, // @emem Indicates the end of signal sequence, works only for repeated signals
                                                       // (e.g. BUSY, RING BACK, etc.)
    
  OTX_CST_CPT_DETECTOR_END_OF_EVENT_CODES
};

typedef enum OtxCstCptDetectorEventCodesE OtxCstCptDetectorEventCodesE;


/******************************************************************************
  @enum 
    CPT Detector Attributes
******************************************************************************/
enum OtxCstCptDetectorAttributesE {
  OTX_ATTR_CST_CPT_DETECTOR_XXX        = OTX_ATTR_END + 0,  // @emem (OTX_ATTRIB_UINT32) Read/Write. 
                                                                  // Minimum required duration (in milliseconds) of a tone
                                                                  // before it is reported as a detected tone.

  OTX_ATTR_CST_CPT_DETECTOR_END                 = OTX_ATTR_END + 1
};

typedef enum OtxCstCptDetectorAttributesE OtxCstCptDetectorAttributesE;




/******************************************************************************
  @enum
    Caller Id Detector Error Result Codes
******************************************************************************/
enum OtxCstCidDetectorResultCodesE {
  OTX_CST_CID_DETECTOR_RES_END                  = OTX_RES_END +  1
};

typedef enum OtxCstCidDetectorResultCodesE OtxCstCidDetectorResultCodesE;


/******************************************************************************
  @enum
    Caller Id Detector Event Codes
******************************************************************************/
enum OtxCstCidDetectorEventCodesE {
  OTX_CST_CID_DETECTOR_DETECTED_CID = 0,     // @emem Caller id detected. 
                                      // The parameter of this event is the caller id result code. 
                                      // A successful caller id detection has the 
                                      // <e OtxCstCidErrorCodesE.OTX_CST_CALLER_ID_EC_NOERROR> value 
                                      // as the <e OtxEventDataS.m_nParam> field of this event. 
                                      // Any other code indicates an error condition.
                                      // The caller id string itself can be read by reading the 
                                      // <e OtxCstCidDectorDeviceAttributesE.OTX_ATTR_CST_CID_DETECTOR_CID_STRING> attribute
                                      // directly after this event has occurred.


  OTX_CST_CID_DETECTOR_END_OF_EVENT_CODES 
};

typedef enum OtxCstCidDetectorEventCodesE OtxCstCidDetectorEventCodesE;


/*******************************************************************************
  @enum 
    Caller Id Detector Device Attributes
*******************************************************************************/
enum OtxCstCidDetectorDeviceAttributesE {
  OTX_ATTR_CST_CID_DETECTOR_CID_STRING      = OTX_ATTR_END + 0, // @emem (OTX_ATTRIB_SZ) Read/Write. Last received Caller Id string as indicated 
                                                                  // by the <e OtxCstCidDetectorEventCodeE.OTX_CST_CID_DETECTED_CID> event. 
                                                                  // This string is reset to '\0' when read or written to. 
                                                                  // <nl> If this string is not read before the next caller id string is received, the caller id string is lost, and 
                                                                  // reading of this attribute will return a <e OtxCommonResultCodesE.OTX_RES_BUSY> return code. 
                                                                  // In that case this attribute has to be written to (any value), in order to clear the "overrun".

  OTX_ATTR_CST_CID_DETECTOR_PRESENTATION_MESSAGE   = OTX_ATTR_END + 1, // @emem (OTX_ATTRIB_OCTETS) Read/Write. Last received Caller Id Presentation message. See <t OtxCstCidPresentationMessageS>.
                                                                  // by the <e OtxCstCidDetectorEventCodeE.OTX_CST_CID_DETECTED_CID> event. 
                                                                  // This message is reset to '\0' when read or written to. 
                                                                  // <nl> If this string is not read before the next caller id string is received, the caller id string is lost, and 
                                                                  // reading of this attribute will return a <e OtxCommonResultCodesE.OTX_RES_BUSY> return code. 
                                                                  // In that case this attribute has to be written to (any value), in order to clear the "overrun".

  OTX_ATTR_CST_CID_DETECTOR_END         = OTX_ATTR_END + 2
};

typedef enum OtxCstCidDetectorDeviceAttributesE OtxCstCidDetectorDeviceAttributesE;




/******************************************************************************
  @enum
    CALLER ID Error Result Codes (Not yet implemented)
******************************************************************************/
enum OtxCstCallerIdResultCodesE {
  OTX_CST_CALLER_ID_RES_END                  = OTX_RES_END +  1
};

typedef enum OtxCstCallerIdResultCodesE OtxCstCallerIdResultCodesE;


/******************************************************************************
  @enum
    CALLER_ID Event Codes ( (Not yet implemented)
******************************************************************************/
enum OtxCstCallerIdEventCodesE {
  OTX_CST_CALLER_ID_DONOTHING , // @emem Passive state
  OTX_CST_CALLER_ID_WAIT      , // @emem Dummy wait state
  OTX_CST_CALLER_ID_DTAS      , // @emem Receives DTAS signal.
  OTX_CST_CALLER_ID_TEACK     , // @emem Generates TEACK signal.
  OTX_CST_CALLER_ID_RPAS      , // @emem Receives RPAS signal (is not available now).
  OTX_CST_CALLER_ID_FSKDET    , // @emem Receives FSK carrier.
  OTX_CST_CALLER_ID_FSK       , // @emem Receives FSK message (including datalink layer).
  OTX_CST_CALLER_ID_R15       , // @emem Russian CallerID decoder (is not available now).
  OTX_CST_CALLER_ID_DTMFDET   , // @emem Receives DTMF-based message and converts it into
                                         // generic data-link layer.
   
  OTX_CST_CALLER_ID_GENERATOR_DONOTHING , // @emem Passive state
  OTX_CST_CALLER_ID_GENERATOR_WAIT      , // @emem Dummy wait state
  OTX_CST_CALLER_ID_GENERATOR_DTASGEN   , // @emem Generates DT-AS signal.
  OTX_CST_CALLER_ID_GENERATOR_TEACKDET  , // @emem Receives TE-ACK signal from TE.
  OTX_CST_CALLER_ID_GENERATOR_DTASTEACK , // @emem Generates DT-AS signal and receives TE-ACK
                                      // signal from TE simultaneously.
  OTX_CST_CALLER_ID_GENERATOR_SAS       , // @emem Generates SAS signal.
  OTX_CST_CALLER_ID_GENERATOR_FSKGEN    , // @emem Generates V.23 of Bell 202 FSK modulated message.
  OTX_CST_CALLER_ID_GENERATOR_DTMFGEN   , // @emem Generates DTMF-based message.

  OTX_CST_CALLER_ID_END_OF_EVENT_CODES
};

typedef enum OtxCstCallerIdEventCodesE OtxCstCallerIdEventCodesE;


/******************************************************************************
  @enum 
    Caller ID Error Codes
******************************************************************************/
enum OtxCstCidErrorCodesE
{
  // Generic errors.
  OTX_CST_CALLER_ID_EC_NOERROR       = 0x00,  // @emem No error.
  OTX_CST_CALLER_ID_EC_TIMEOUT       = 0x01,  // @emem Time out occured
  OTX_CST_CALLER_ID_EC_INVALID_STATE = 0x02,  // @emem Invalid state

  // Errors for CIDCHIP_FSK state.
  OTX_CST_CALLER_ID_EC_CHECKSUMERROR = 0x10,  // @emem Message checksum error
  OTX_CST_CALLER_ID_EC_ILLEGALLENGTH = 0x11,  // @emem Illegal message length
  OTX_CST_CALLER_ID_EC_UNKNOWNTYPE   = 0x12,  // @emem Unknown message type

  // Otx additions
  OTX_CST_CALLER_ID_EC_INVALIDNUMBER = 0x77   // @emem Decoded number is invalid 
};

typedef enum OtxCstCidErrorCodesE OtxCstCidErrorCodesE;


/******************************************************************************
  @enum 
    Caller ID Attributes
******************************************************************************/
enum OtxCstCallerIdAttributesE {
  OTX_ATTR_CST_CALLER_ID_XXX                 = OTX_ATTR_END + 0,  // @emem (OTX_ATTRIB_UINT32) Read/Write. 
                                                                  // Dummy

  OTX_ATTR_CST_CALLER_ID_END                 = OTX_ATTR_END + 1
};

typedef enum OtxCstCallerIdAttributesE OtxCstCallerIdAttributesE;


/*******************************************************************************

  @struct
    Specific details of the current Caller Id message. This structure is returned by 
    the function <f OtxT1E1GetLayer1StatusEx>. 

  @xref
    <f OtxT1E1GetLayer1StatusEx>

*******************************************************************************/
struct OtxCstCidPresentationMessageS
{
  OTX_UINT16  type;                     // @field Message type.
  OTX_UINT16  date[9];                  // @field  Date and the time of a call.
  OTX_UINT16  callingLineIdentity[21];  // @field  Calling line identity - number (including area code).
  OTX_UINT16  calledLineIdentity[21];   // @field  Called line identity  - number (including area code).
  OTX_UINT16  callingPartyName[51];     // @field  The name of the party ta the origin of a call.
  OTX_UINT16  firstLineIdentity[21];    // @field  In case of forwarded call, it identifiesthe first called party.
  OTX_UINT16  redirectedNumber[21];     // @field  In case of forwarded call only.
  OTX_UINT16  complementaryCallingLineIdentity[21]; //  @field Other Calling Line Identity
  OTX_UINT16  reasonForAbsence;         // @field Reason for absence of calling line identity:
                                        //  <nl> 'O' - Unavailable (probably out of range)
                                        //  <nl> 'P' - Private (CLIR involved) call
  OTX_UINT16  reasonForAbsenceOfParty;  // @field Reason for absence of Calling Party Name:
                                        // <nl>  'O' - Unavailable
                                        // <nl>  'P' - Private (CLIR involved) call
  OTX_UINT16  callType;                 // @field Specifies the type of a call:
                                        // <nl>  0x01 - Voice Call
                                        // <nl>  0x02 - CLI Ring Back in case of free call
                                        // <nl>  0x03 - Calling Name Delivery
                                        // <nl>  0x07 - Set Clock
                                        // <nl>  0x81 - Message Waiting Call
  OTX_UINT16  visualIndicator;          // @field Switches on/off visual indicator
                                        // (presence of waiting messages).
  OTX_UINT16  networkMessageSystemStatus;  // @field Specifies the number of waiting messages
                                        // in the network message system.
                                        // Zero value means no messages, value of 1 means
                                        // 1 or unspecified number of messages in the queue,
                                        // other values indicate the number of waiting messges.
  OTX_UINT16  typeOfForwardedCall;      // @field Identifies the type of forwarded call
                                        // <nl>  0x01 - Call forwarded on busy
                                        // <nl>  0x02 - Call forwarded on no reply
                                        // <nl>  0x03 - Unconditional forwarded call
                                        // <nl>  0x04 - Deflected call (after alerting)
                                        // <nl>  0x05 - Deflected call (immediate)
                                        // <nl>  0x06 - Call forwarded on inability to reach mobile subscriber
  OTX_UINT16  typeOfCallingUser;        // @field Identifies the type of calling user:
                                        // <nl>  0x00 - Origination unknown or unavailable
                                        // <nl>  0x03 - Virtual Private Network
                                        // <nl>  0x04 - Mobile phone
                                        // <nl>  0x05 - Mobile phone + Virtual Private Network
                                        // <nl>  0x0a - Ordinary calling subscriber
                                        // <nl>  0x0b - Calling subscriber with priority
                                        // <nl>  0x0c - Data Call
                                        // <nl>  0x0d - Test Call
                                        // <nl>  0x0f - Payphone
  OTX_UINT16  extension[10];            // @field Extension for network operator use.
  OTX_UINT16 lastError;                 // @field Last error:
                                        // <nl>  0x00 - no error
                                        // <nl>  0x10 - checksum error
                                        // <nl>  0x11 - frame length error (unrecoverable)
                                        // <nl>  0x12 - unrecognized message type (unrecoverable)
  OTX_INT16  validFields;               // @field Bit mask for available fields (see below):
                                        // <nl> 0x0001 - date field is valid
                                        // <nl> 0x0002 - callingLineIdentity field is valid
                                        // <nl> 0x0004 - calledLineIdentity field is valid
                                        // <nl> 0x0008 - callingPartyName field is valid
                                        // <nl> 0x0010 - firstLineIdentity field is valid
                                        // <nl> 0x0020 - redirectedNumber field is valid
                                        // <nl> 0x0040 - complementaryCallingLineIdentity field is valid
                                        // <nl> 0x0080 - reasonForAbsence field is valid
                                        // <nl> 0x0100 - reasonForAbsenceOfParty field is valid
                                        // <nl> 0x0200 - callType field is valid
                                        // <nl> 0x0400 - visualIndicator field is valid
                                        // <nl> 0x0800 - networkMessageSystemStatus field is valid
                                        // <nl> 0x1000 - extension field is valid
                                        // <nl> 0x2000 - typeOfForwardedCall field is valid
                                        // <nl> 0x4000   typeOfCallingUser field is valid
};

typedef struct OtxCstCidPresentationMessageS OtxCstCidPresentationMessageS;

/******************************************************************************
  @enum 
    Valid fields in <t OtxCstCidPresentationMessageS>.
******************************************************************************/
enum OtxCstCidPresentationMessageValidFieldsE {
  OTX_CID_VALIDDATE                             = 0x0001,  // @emem date field is valid
  OTX_CID_VALIDCALLINGLINEIDENTITY              = 0x0002,  // @emem callingLineIdentity field is valid
  OTX_CID_VALIDCALLEDLINEIDENTITY               = 0x0004,  // @emem calledLineIdentity field is valid
  OTX_CID_VALIDCALLINGPARTYNAME                 = 0x0008,  // @emem callingPartyName field is valid
  OTX_CID_VALIDFIRSTLINEIDENTITY                = 0x0010,  // @emem firstLineIdentity field is valid
  OTX_CID_VALIDREDIRECTEDNUMBER                 = 0x0020,  // @emem redirectedNumber field is valid
  OTX_CID_VALIDCOMPLEMENTARYCALLINGLINEIDENTITY = 0x0040,  // @emem complementaryCallingLineIdentity field is valid
  OTX_CID_VALIDREASONFORABSENCE                 = 0x0080,  // @emem reasonForAbsence field is valid
  OTX_CID_VALIDREASONFORABSENCEOFPARTY          = 0x0100,  // @emem reasonForAbsenceOfParty field is valid
  OTX_CID_VALIDCALLTYPE                         = 0x0200,  // @emem callType field is valid
  OTX_CID_VALIDVISUALINDICATOR                  = 0x0400,  // @emem visualIndicator field is valid
  OTX_CID_VALIDNETWORKMESSAGESYSTEMSTATUS       = 0x0800,  // @emem networkMessageSystemStatus field is valid
  OTX_CID_VALIDEXTENSION                        = 0x1000,  // @emem extension field is valid
  OTX_CID_VALIDTYPEOFFORWARDEDCALL              = 0x2000,  // @emem typeOfForwardedCall field is valid
  OTX_CID_VALIDTYPEOFCALLINGUSER                = 0x4000,  // @emem typeOfCallingUser field is valid
  OTX_CID_VALIDLASTERROR                        = 0x8000   // @emem lastError field is valid
};

typedef enum OtxCstCidPresentationMessageValidFieldsE OtxCstCidPresentationMessageValidFieldsE;



/******************************************************************************
  @enum 
    Gain of generated tones
******************************************************************************/
enum OtxCstGainE {
  OTX_CST_GAIN_0DB           = 0,  // @emem Full Gain
  OTX_CST_GAIN_DG_MINUS_3DB  = 1,  // @emem -3dB Gain
  OTX_CST_GAIN_DG_MINUS_6DB  = 2,  // @emem -6dB Gain
  OTX_CST_GAIN_DG_MINUS_9DB  = 3,  // @emem -9dB Gain
  OTX_CST_GAIN_DG_MINUS_12DB = 4,  // @emem -12dB Gain
  OTX_CST_GAIN_DG_MINUS_15DB = 5   // @emem -15dB Gain
};

typedef enum OtxCstGainE OtxCstGainE;


/******************************************************************************
  @enum 
    Maximum echo path options for the G.165/G.168 echo canceller.
******************************************************************************/
enum OtxCstEchoCancelMaxEchoPathE {
  OTX_CST_ECHO_CANCEL_16_MS  = 16,  // @emem 16 millisecond maximum echo path
  OTX_CST_ECHO_CANCEL_32_MS  = 32,  // @emem 32 millisecond maximum echo path
  OTX_CST_ECHO_CANCEL_64_MS  = 64,  // @emem 64 millisecond maximum echo path
};

typedef enum OtxCstEchoCancelMaxEchoPathE OtxCstEchoCancelMaxEchoPathE;


/******************************************************************************
  @enum 
    The Echo Cancel device uses two input pipes, one Far End (Reference) 
    one Near End. This enumeration is used in the <p iFromConnectPoint> 
    or <p iToConnectPoint> parameter <f OtxDrvConnectionLogicalDevice>
    call to specify which connection is the Near End, and which connection
    is the Far End.
******************************************************************************/
enum OtxCstEchoCancelConnectionPointsE {
  OTX_CST_ECHO_CANCEL_NEAR_END_PIPE = 0,  // @emem The Near End pipe which contains the signal with the echo
  OTX_CST_ECHO_CANCEL_FAR_END_PIPE  = 1   // @emem The Far End pipe which is the reference signal that the echo cancel device with filter out fron the Near End pipe
};

typedef enum OtxCstEchoCancelConnectionPointsE OtxCstEchoCancelConnectionPointsE;


/******************************************************************************
  @enum 
    Configuration options for the Call Progress Tone (CPT) detector
******************************************************************************/
enum OtxCstCptDetectorConfigurationE {
  OTX_CST_CPT_DETECTOR_Q35_CFG     = 0,  // @emem Call progress tone configuration according to Q.35
  OTX_CST_CPT_DETECTOR_Q35_EX_CFG  = 1,  // @emem Call progress tone configuration according to Q.35 + BusyTone for Singapore + RingBackTone (2-pulse) + DialTone for Italy

  OTX_CST_CPT_DETECTOR_CFG_END     = 2  
};

typedef enum OtxCstCptDetectorConfigurationE OtxCstCptDetectorConfigurationE;

/******************************************************************************
  @enum 
    Configuration options for the Caller ID (CID) detector
******************************************************************************/
enum OtxCstCidDetectorConfigurationE {
  OTX_CST_CID_DETECTOR_STD_CFG     = 0,   // @emem Standard Caller ID configuration

  OTX_CST_CID_DETECTOR_CFG_END     = 1  
};

typedef enum OtxCstCidDetectorConfigurationE OtxCstCidDetectorConfigurationE;


/******************************************************************************
  @enum 
    Configuration options for the Call Progress Tone (CPT) detector
******************************************************************************/
enum OtxCstCptGeneratorConfigurationE {
  OTX_CST_CPT_GENERATOR_USA_CFG     = 0,  // @emem Call progress tone configuration according to the standards in the U.S.A.
  OTX_CST_CPT_GENERATOR_KOREA_CFG   = 1,  // @emem Call progress tone configuration according to the standards in Korea.

  OTX_CST_CPT_GENERATOR_CFG_END     = 2  
};

typedef enum OtxCstCptGeneratorConfigurationE OtxCstCptGeneratorConfigurationE;


/******************************************************************************
  @enum 
    Call Progress Generator Tones
******************************************************************************/
enum OtxCstCptGeneratorToneE {
  OTX_CST_CPT_GENERATOR_NO_TONE       = 0x0000,  // @emem Silence, No tone
  OTX_CST_CPT_GENERATOR_DIAL_TONE     = 0x2001,  // @emem Dial Tone
  OTX_CST_CPT_GENERATOR_RING_TONE     = 0x2002,  // @emem Ring Tone
  OTX_CST_CPT_GENERATOR_BUSY_TONE     = 0x2003,  // @emem Busy Tone
  OTX_CST_CPT_GENERATOR_FASTBUSY_TONE = 0x2004,  // @emem FastBusy Tone
};

typedef enum OtxCstCptGeneratorToneE OtxCstCptGeneratorToneE;


/******************************************************************************
  @enum 
    Call Progress Detector Tones
******************************************************************************/
enum OtxCstCptDetectorToneE {
  OTX_CST_CPT_DETECTOR_NO_TONE        = 0,  // @emem Silence, No tone
  OTX_CST_CPT_DETECTOR_DIAL_TONE      = 1,  // @emem Dial Tone
  OTX_CST_CPT_DETECTOR_RING_TONE      = 2,  // @emem Ring Tone
  OTX_CST_CPT_DETECTOR_BUSY_TONE      = 3,  // @emem Busy Tone
  OTX_CST_CPT_DETECTOR_FASTBUSY_TONE  = 4,  // @emem FastBusy Tone
  OTX_CST_CPT_DETECTOR_LONG_TONE      = 5,  // @emem Long lasting tone for 1 second
  OTX_CST_CPT_DETECTOR_END_OF_TONE    = 6,  // @emem End of current tone
};

typedef enum OtxCstCptDetectorToneE OtxCstCptDetectorToneE;





#ifdef __cplusplus
  } // extern "C"
#endif


/*******************************************************************************

  Copyright (C) Odin TeleSystems Inc., 2004 - 2005


  All rights reserved. No part of this computer program may be reproduced,
  stored in any retrieval system, or transmitted, in any form or by any
  means, electronic, mechanical, photocopying, recording, or otherwise,
  without the prior written permission of Odin TeleSystems Inc., or without
  a permission stipulated in the agreement/contract under which this computer
  program was supplied.

*******************************************************************************/
#endif // OTX_CST_DEF_H
